# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ..v0 import common_pb2 as _common_pb2
from ..v1 import mediator_pb2 as _mediator_pb2
from ..v1 import mediator_response_pb2 as _mediator_response_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.rpc import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionResultMessage(_message.Message):
    __slots__ = ("request_id", "verdict", "root_hash", "domain_id")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    verdict: Verdict
    root_hash: bytes
    domain_id: str
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., verdict: _Optional[_Union[Verdict, _Mapping]] = ..., root_hash: _Optional[bytes] = ..., domain_id: _Optional[str] = ...) -> None: ...

class Verdict(_message.Message):
    __slots__ = ("approve", "participant_reject", "mediator_reject")
    APPROVE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_REJECT_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_REJECT_FIELD_NUMBER: _ClassVar[int]
    approve: _empty_pb2.Empty
    participant_reject: ParticipantReject
    mediator_reject: _mediator_pb2.MediatorReject
    def __init__(self, approve: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., participant_reject: _Optional[_Union[ParticipantReject, _Mapping]] = ..., mediator_reject: _Optional[_Union[_mediator_pb2.MediatorReject, _Mapping]] = ...) -> None: ...

class ParticipantReject(_message.Message):
    __slots__ = ("reasons",)
    REASONS_FIELD_NUMBER: _ClassVar[int]
    reasons: _containers.RepeatedCompositeFieldContainer[RejectionReason]
    def __init__(self, reasons: _Optional[_Iterable[_Union[RejectionReason, _Mapping]]] = ...) -> None: ...

class RejectionReason(_message.Message):
    __slots__ = ("parties", "reject")
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    REJECT_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    reject: _mediator_response_pb2.LocalReject
    def __init__(self, parties: _Optional[_Iterable[str]] = ..., reject: _Optional[_Union[_mediator_response_pb2.LocalReject, _Mapping]] = ...) -> None: ...

class TransferResult(_message.Message):
    __slots__ = ("request_id", "source_domain", "target_domain", "informees", "verdict")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    TARGET_DOMAIN_FIELD_NUMBER: _ClassVar[int]
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    VERDICT_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    source_domain: str
    target_domain: str
    informees: _containers.RepeatedScalarFieldContainer[str]
    verdict: Verdict
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., source_domain: _Optional[str] = ..., target_domain: _Optional[str] = ..., informees: _Optional[_Iterable[str]] = ..., verdict: _Optional[_Union[Verdict, _Mapping]] = ...) -> None: ...

class MediatorReject(_message.Message):
    __slots__ = ("reason",)
    REASON_FIELD_NUMBER: _ClassVar[int]
    reason: _status_pb2.Status
    def __init__(self, reason: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...) -> None: ...

class MalformedMediatorRequestResult(_message.Message):
    __slots__ = ("request_id", "domain_id", "view_type", "rejection")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    REJECTION_FIELD_NUMBER: _ClassVar[int]
    request_id: _timestamp_pb2.Timestamp
    domain_id: str
    view_type: _common_pb2.ViewType
    rejection: MediatorReject
    def __init__(self, request_id: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ..., rejection: _Optional[_Union[MediatorReject, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v1/ledger_offset.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v1/ledger_offset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*com/daml/ledger/api/v1/ledger_offset.proto\x12\x16\x63om.daml.ledger.api.v1\"\xbc\x01\n\x0cLedgerOffset\x12\x1c\n\x08\x61\x62solute\x18\x01 \x01(\tH\x00R\x08\x61\x62solute\x12Q\n\x08\x62oundary\x18\x02 \x01(\x0e\x32\x33.com.daml.ledger.api.v1.LedgerOffset.LedgerBoundaryH\x00R\x08\x62oundary\"2\n\x0eLedgerBoundary\x12\x10\n\x0cLEDGER_BEGIN\x10\x00\x12\x0e\n\nLEDGER_END\x10\x01\x42\x07\n\x05valueB\x90\x01\n\x16\x63om.daml.ledger.api.v1B\x16LedgerOffsetOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\xaa\x02\x16\x43om.Daml.Ledger.Api.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v1.ledger_offset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v1B\026LedgerOffsetOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v1\252\002\026Com.Daml.Ledger.Api.V1'
  _globals['_LEDGEROFFSET']._serialized_start=71
  _globals['_LEDGEROFFSET']._serialized_end=259
  _globals['_LEDGEROFFSET_LEDGERBOUNDARY']._serialized_start=200
  _globals['_LEDGEROFFSET_LEDGERBOUNDARY']._serialized_end=250
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SharedContractsState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    STATE_UNSPECIFIED: _ClassVar[SharedContractsState]
    SHARED_CONTRACTS: _ClassVar[SharedContractsState]
    NO_SHARED_CONTRACTS: _ClassVar[SharedContractsState]
STATE_UNSPECIFIED: SharedContractsState
SHARED_CONTRACTS: SharedContractsState
NO_SHARED_CONTRACTS: SharedContractsState

class SetSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: PruningSchedule
        def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class GetSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: PruningSchedule
        def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...

class SetParticipantSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: ParticipantPruningSchedule
        def __init__(self, schedule: _Optional[_Union[ParticipantPruningSchedule, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class GetParticipantSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ("schedule",)
        SCHEDULE_FIELD_NUMBER: _ClassVar[int]
        schedule: ParticipantPruningSchedule
        def __init__(self, schedule: _Optional[_Union[ParticipantPruningSchedule, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...

class PruningSchedule(_message.Message):
    __slots__ = ("cron", "max_duration", "retention")
    CRON_FIELD_NUMBER: _ClassVar[int]
    MAX_DURATION_FIELD_NUMBER: _ClassVar[int]
    RETENTION_FIELD_NUMBER: _ClassVar[int]
    cron: str
    max_duration: _duration_pb2.Duration
    retention: _duration_pb2.Duration
    def __init__(self, cron: _Optional[str] = ..., max_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., retention: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class ParticipantPruningSchedule(_message.Message):
    __slots__ = ("schedule", "prune_internally_only")
    SCHEDULE_FIELD_NUMBER: _ClassVar[int]
    PRUNE_INTERNALLY_ONLY_FIELD_NUMBER: _ClassVar[int]
    schedule: PruningSchedule
    prune_internally_only: bool
    def __init__(self, schedule: _Optional[_Union[PruningSchedule, _Mapping]] = ..., prune_internally_only: bool = ...) -> None: ...

class ClearSchedule(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class SetCron(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("cron",)
        CRON_FIELD_NUMBER: _ClassVar[int]
        cron: str
        def __init__(self, cron: _Optional[str] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class SetMaxDuration(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("max_duration",)
        MAX_DURATION_FIELD_NUMBER: _ClassVar[int]
        max_duration: _duration_pb2.Duration
        def __init__(self, max_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class SetRetention(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("retention",)
        RETENTION_FIELD_NUMBER: _ClassVar[int]
        retention: _duration_pb2.Duration
        def __init__(self, retention: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    def __init__(self) -> None: ...

class LocatePruningTimestamp(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("index",)
        INDEX_FIELD_NUMBER: _ClassVar[int]
        index: int
        def __init__(self, index: _Optional[int] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("timestamp",)
        TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        timestamp: _timestamp_pb2.Timestamp
        def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...

class SetNoWaitCommitmentsFrom(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("counter_participant_uids", "sequencing_timestamp", "pruning_offset", "domain_ids")
        COUNTER_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
        SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
        PRUNING_OFFSET_FIELD_NUMBER: _ClassVar[int]
        DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
        counter_participant_uids: _containers.RepeatedScalarFieldContainer[str]
        sequencing_timestamp: _timestamp_pb2.Timestamp
        pruning_offset: str
        domain_ids: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, counter_participant_uids: _Optional[_Iterable[str]] = ..., sequencing_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., pruning_offset: _Optional[str] = ..., domain_ids: _Optional[_Iterable[str]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("participant_domains_mapping",)
        class ParticipantDomainsMappingEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: Domains
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Domains, _Mapping]] = ...) -> None: ...
        PARTICIPANT_DOMAINS_MAPPING_FIELD_NUMBER: _ClassVar[int]
        participant_domains_mapping: _containers.MessageMap[str, Domains]
        def __init__(self, participant_domains_mapping: _Optional[_Mapping[str, Domains]] = ...) -> None: ...
    def __init__(self) -> None: ...

class ResetNoWaitCommitmentsFrom(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("counter_participant_uids", "domain_ids")
        COUNTER_PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
        DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
        counter_participant_uids: _containers.RepeatedScalarFieldContainer[str]
        domain_ids: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, counter_participant_uids: _Optional[_Iterable[str]] = ..., domain_ids: _Optional[_Iterable[str]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("participant_domains_mapping",)
        class ParticipantDomainsMappingEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: Domains
            def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Domains, _Mapping]] = ...) -> None: ...
        PARTICIPANT_DOMAINS_MAPPING_FIELD_NUMBER: _ClassVar[int]
        participant_domains_mapping: _containers.MessageMap[str, Domains]
        def __init__(self, participant_domains_mapping: _Optional[_Mapping[str, Domains]] = ...) -> None: ...
    def __init__(self) -> None: ...

class Domains(_message.Message):
    __slots__ = ("domain_ids",)
    DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
    domain_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, domain_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetNoWaitCommitmentsFrom(_message.Message):
    __slots__ = ()
    class Request(_message.Message):
        __slots__ = ("domain_ids", "participant_uids")
        DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
        PARTICIPANT_UIDS_FIELD_NUMBER: _ClassVar[int]
        domain_ids: _containers.RepeatedScalarFieldContainer[str]
        participant_uids: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, domain_ids: _Optional[_Iterable[str]] = ..., participant_uids: _Optional[_Iterable[str]] = ...) -> None: ...
    class Response(_message.Message):
        __slots__ = ("ignored_participants", "not_ignored_participants")
        IGNORED_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
        NOT_IGNORED_PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
        ignored_participants: _containers.RepeatedCompositeFieldContainer[NoWaitCommitmentsSetup]
        not_ignored_participants: _containers.RepeatedCompositeFieldContainer[WaitCommitmentsSetup]
        def __init__(self, ignored_participants: _Optional[_Iterable[_Union[NoWaitCommitmentsSetup, _Mapping]]] = ..., not_ignored_participants: _Optional[_Iterable[_Union[WaitCommitmentsSetup, _Mapping]]] = ...) -> None: ...
    def __init__(self) -> None: ...

class NoWaitCommitmentsSetup(_message.Message):
    __slots__ = ("counter_participant_uid", "sequencing_timestamp", "pruning_offset", "domain_ids", "counter_participant_state")
    COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCING_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    PRUNING_OFFSET_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
    COUNTER_PARTICIPANT_STATE_FIELD_NUMBER: _ClassVar[int]
    counter_participant_uid: str
    sequencing_timestamp: _timestamp_pb2.Timestamp
    pruning_offset: str
    domain_ids: Domains
    counter_participant_state: SharedContractsState
    def __init__(self, counter_participant_uid: _Optional[str] = ..., sequencing_timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., pruning_offset: _Optional[str] = ..., domain_ids: _Optional[_Union[Domains, _Mapping]] = ..., counter_participant_state: _Optional[_Union[SharedContractsState, str]] = ...) -> None: ...

class WaitCommitmentsSetup(_message.Message):
    __slots__ = ("counter_participant_uid", "domain_ids", "counter_participant_state")
    COUNTER_PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_IDS_FIELD_NUMBER: _ClassVar[int]
    COUNTER_PARTICIPANT_STATE_FIELD_NUMBER: _ClassVar[int]
    counter_participant_uid: str
    domain_ids: Domains
    counter_participant_state: SharedContractsState
    def __init__(self, counter_participant_uid: _Optional[str] = ..., domain_ids: _Optional[_Union[Domains, _Mapping]] = ..., counter_participant_state: _Optional[_Union[SharedContractsState, str]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .pruning_pb2 import ClearSchedule, Domains, GetNoWaitCommitmentsFrom, GetParticipantSchedule, GetSchedule, LocatePruningTimestamp, NoWaitCommitmentsSetup, ParticipantPruningSchedule, PruningSchedule, ResetNoWaitCommitmentsFrom, SetCron, SetMaxDuration, SetNoWaitCommitmentsFrom, SetParticipantSchedule, SetRetention, SetSchedule, SharedContractsState, WaitCommitmentsSetup

__all__ = [
    "ClearSchedule",
    "Domains",
    "GetNoWaitCommitmentsFrom",
    "GetParticipantSchedule",
    "GetSchedule",
    "LocatePruningTimestamp",
    "NoWaitCommitmentsSetup",
    "ParticipantPruningSchedule",
    "PruningSchedule",
    "ResetNoWaitCommitmentsFrom",
    "SetCron",
    "SetMaxDuration",
    "SetNoWaitCommitmentsFrom",
    "SetParticipantSchedule",
    "SetRetention",
    "SetSchedule",
    "SharedContractsState",
    "WaitCommitmentsSetup",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v2/topology.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v2/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v1 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_topology__pb2
from . import domain_params_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v2_dot_domain__params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2com/digitalasset/canton/protocol/v2/topology.proto\x12#com.digitalasset.canton.protocol.v2\x1a\x32\x63om/digitalasset/canton/protocol/v1/topology.proto\x1a\x37\x63om/digitalasset/canton/protocol/v2/domain_params.proto\"\x9b\x01\n\x16\x44omainParametersChange\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12i\n\x11\x64omain_parameters\x18\x02 \x01(\x0b\x32<.com.digitalasset.canton.protocol.v2.DynamicDomainParametersR\x10\x64omainParameters\"\xa1\x01\n\x1b\x44omainGovernanceTransaction\x12w\n\x18\x64omain_parameters_change\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.protocol.v2.DomainParametersChangeH\x00R\x16\x64omainParametersChangeB\t\n\x07mapping\"\xf4\x01\n\x13TopologyTransaction\x12]\n\x0cstate_update\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v1.TopologyStateUpdateH\x00R\x0bstateUpdate\x12o\n\x11\x64omain_governance\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v2.DomainGovernanceTransactionH\x00R\x10\x64omainGovernanceB\r\n\x0btransactionBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v2.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v2'
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_start=201
  _globals['_DOMAINPARAMETERSCHANGE']._serialized_end=356
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_start=359
  _globals['_DOMAINGOVERNANCETRANSACTION']._serialized_end=520
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=523
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=767
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UntypedVersionedMessage(_message.Message):
    __slots__ = ("data", "version")
    DATA_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    version: int
    def __init__(self, data: _Optional[bytes] = ..., version: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v0/initialization_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v0/initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/topology/admin/v0/initialization_service.proto\x12)com.digitalasset.canton.topology.admin.v0\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"m\n\rInitIdRequest\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12 \n\x0b\x66ingerprint\x18\x02 \x01(\tR\x0b\x66ingerprint\x12\x1a\n\x08instance\x18\x03 \x01(\tR\x08instance\"Y\n\x0eInitIdResponse\x12+\n\x11unique_identifier\x18\x01 \x01(\tR\x10uniqueIdentifier\x12\x1a\n\x08instance\x18\x02 \x01(\tR\x08instance\"z\n\rGetIdResponse\x12 \n\x0binitialized\x18\x01 \x01(\x08R\x0binitialized\x12+\n\x11unique_identifier\x18\x02 \x01(\tR\x10uniqueIdentifier\x12\x1a\n\x08instance\x18\x03 \x01(\tR\x08instance2\xb4\x02\n\x15InitializationService\x12}\n\x06InitId\x12\x38.com.digitalasset.canton.topology.admin.v0.InitIdRequest\x1a\x39.com.digitalasset.canton.topology.admin.v0.InitIdResponse\x12Y\n\x05GetId\x12\x16.google.protobuf.Empty\x1a\x38.com.digitalasset.canton.topology.admin.v0.GetIdResponse\x12\x41\n\x0b\x43urrentTime\x12\x16.google.protobuf.Empty\x1a\x1a.google.protobuf.TimestampBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v0.initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v0'
  _globals['_INITIDREQUEST']._serialized_start=179
  _globals['_INITIDREQUEST']._serialized_end=288
  _globals['_INITIDRESPONSE']._serialized_start=290
  _globals['_INITIDRESPONSE']._serialized_end=379
  _globals['_GETIDRESPONSE']._serialized_start=381
  _globals['_GETIDRESPONSE']._serialized_end=503
  _globals['_INITIALIZATIONSERVICE']._serialized_start=506
  _globals['_INITIALIZATIONSERVICE']._serialized_end=814
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.rpc import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LocalVerdict(_message.Message):
    __slots__ = ("code", "reason")
    class VerdictCode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        VERDICT_CODE_UNSPECIFIED: _ClassVar[LocalVerdict.VerdictCode]
        VERDICT_CODE_LOCAL_APPROVE: _ClassVar[LocalVerdict.VerdictCode]
        VERDICT_CODE_LOCAL_REJECT: _ClassVar[LocalVerdict.VerdictCode]
        VERDICT_CODE_LOCAL_MALFORMED: _ClassVar[LocalVerdict.VerdictCode]
    VERDICT_CODE_UNSPECIFIED: LocalVerdict.VerdictCode
    VERDICT_CODE_LOCAL_APPROVE: LocalVerdict.VerdictCode
    VERDICT_CODE_LOCAL_REJECT: LocalVerdict.VerdictCode
    VERDICT_CODE_LOCAL_MALFORMED: LocalVerdict.VerdictCode
    CODE_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    code: LocalVerdict.VerdictCode
    reason: _status_pb2.Status
    def __init__(self, code: _Optional[_Union[LocalVerdict.VerdictCode, str]] = ..., reason: _Optional[_Union[_status_pb2.Status, _Mapping]] = ...) -> None: ...

class ConfirmationResponse(_message.Message):
    __slots__ = ("request_id", "sender", "local_verdict", "root_hash", "confirming_parties", "domain_id", "view_position")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    LOCAL_VERDICT_FIELD_NUMBER: _ClassVar[int]
    ROOT_HASH_FIELD_NUMBER: _ClassVar[int]
    CONFIRMING_PARTIES_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_POSITION_FIELD_NUMBER: _ClassVar[int]
    request_id: int
    sender: str
    local_verdict: LocalVerdict
    root_hash: bytes
    confirming_parties: _containers.RepeatedScalarFieldContainer[str]
    domain_id: str
    view_position: ViewPosition
    def __init__(self, request_id: _Optional[int] = ..., sender: _Optional[str] = ..., local_verdict: _Optional[_Union[LocalVerdict, _Mapping]] = ..., root_hash: _Optional[bytes] = ..., confirming_parties: _Optional[_Iterable[str]] = ..., domain_id: _Optional[str] = ..., view_position: _Optional[_Union[ViewPosition, _Mapping]] = ...) -> None: ...

class ViewPosition(_message.Message):
    __slots__ = ("position",)
    POSITION_FIELD_NUMBER: _ClassVar[int]
    position: _containers.RepeatedCompositeFieldContainer[MerkleSeqIndex]
    def __init__(self, position: _Optional[_Iterable[_Union[MerkleSeqIndex, _Mapping]]] = ...) -> None: ...

class MerkleSeqIndex(_message.Message):
    __slots__ = ("is_right",)
    IS_RIGHT_FIELD_NUMBER: _ClassVar[int]
    is_right: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, is_right: _Optional[_Iterable[bool]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TraceContext(_message.Message):
    __slots__ = ("traceparent", "tracestate")
    TRACEPARENT_FIELD_NUMBER: _ClassVar[int]
    TRACESTATE_FIELD_NUMBER: _ClassVar[int]
    traceparent: _wrappers_pb2.StringValue
    tracestate: _wrappers_pb2.StringValue
    def __init__(self, traceparent: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ..., tracestate: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from collections import defaultdict
from os.path import basename, dirname
from pathlib import Path
from typing import DefaultDict, Set

from google.protobuf.descriptor_pb2 import FileDescriptorSet

from ..syntax.python import all_decl
from .python_header import HEADER
from .util import get_root_name

__all__ = ["write_init_files"]


def write_init_files(fds: FileDescriptorSet, to: Path) -> None:
    """
    Write __init__.py files next to the generated Protobuf files.
    """
    plan = defaultdict(list)

    # organize our Protobuf files by enclosing directory
    for fd in fds.file:
        if (
            fd.name.startswith("com/daml") or fd.name.startswith("com/digitalasset")
        ) and not fd.name.endswith(".pyi"):
            plan[dirname(fd.name)].append(fd)

    # for each directory we identified, make sure there is an entry for all of their parent
    # directories too; we may also want to generate empty __init__ files
    for directory in list(plan):
        components = directory.split("/")
        for i in range(0, len(components)):
            _ = plan["/".join(components[:i])]

    for directory, files in plan.items():
        import_map = defaultdict(set)  # type: DefaultDict[str, Set[str]]
        for file in files:
            current_module_base = basename(get_root_name(file.name)[0])

            current_module_pb = "." + current_module_base + "_pb2"
            current_module_grpc = "." + current_module_base + "_pb2_grpc"
            for e in file.enum_type:
                import_map[current_module_pb].add(e.name)
            for m in file.message_type:
                import_map[current_module_pb].add(m.name)
            for s in file.service:
                import_map[current_module_grpc].add(s.name + "Stub")

        d = to / directory
        d.mkdir(parents=True, exist_ok=True)
        p = d / "__init__.py"
        with p.open("w") as buf:
            buf.write(HEADER)
            buf.write("\n")

            all_symbols = set()  # type: Set[str]
            for f, imports in import_map.items():
                buf.write(f"from {f} import {', '.join(sorted(imports))}\n")
                all_symbols.update(imports)
            buf.write("\n")
            buf.write(all_decl(sorted(all_symbols)))



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import event_pb2 as _event_pb2
from . import reassignment_pb2 as _reassignment_pb2
from . import transaction_filter_pb2 as _transaction_filter_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ParticipantPermission(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PARTICIPANT_PERMISSION_UNSPECIFIED: _ClassVar[ParticipantPermission]
    PARTICIPANT_PERMISSION_SUBMISSION: _ClassVar[ParticipantPermission]
    PARTICIPANT_PERMISSION_CONFIRMATION: _ClassVar[ParticipantPermission]
    PARTICIPANT_PERMISSION_OBSERVATION: _ClassVar[ParticipantPermission]
PARTICIPANT_PERMISSION_UNSPECIFIED: ParticipantPermission
PARTICIPANT_PERMISSION_SUBMISSION: ParticipantPermission
PARTICIPANT_PERMISSION_CONFIRMATION: ParticipantPermission
PARTICIPANT_PERMISSION_OBSERVATION: ParticipantPermission

class GetActiveContractsRequest(_message.Message):
    __slots__ = ("filter", "verbose", "active_at_offset")
    FILTER_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_AT_OFFSET_FIELD_NUMBER: _ClassVar[int]
    filter: _transaction_filter_pb2.TransactionFilter
    verbose: bool
    active_at_offset: int
    def __init__(self, filter: _Optional[_Union[_transaction_filter_pb2.TransactionFilter, _Mapping]] = ..., verbose: bool = ..., active_at_offset: _Optional[int] = ...) -> None: ...

class GetActiveContractsResponse(_message.Message):
    __slots__ = ("workflow_id", "active_contract", "incomplete_unassigned", "incomplete_assigned")
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_CONTRACT_FIELD_NUMBER: _ClassVar[int]
    INCOMPLETE_UNASSIGNED_FIELD_NUMBER: _ClassVar[int]
    INCOMPLETE_ASSIGNED_FIELD_NUMBER: _ClassVar[int]
    workflow_id: str
    active_contract: ActiveContract
    incomplete_unassigned: IncompleteUnassigned
    incomplete_assigned: IncompleteAssigned
    def __init__(self, workflow_id: _Optional[str] = ..., active_contract: _Optional[_Union[ActiveContract, _Mapping]] = ..., incomplete_unassigned: _Optional[_Union[IncompleteUnassigned, _Mapping]] = ..., incomplete_assigned: _Optional[_Union[IncompleteAssigned, _Mapping]] = ...) -> None: ...

class ActiveContract(_message.Message):
    __slots__ = ("created_event", "domain_id", "reassignment_counter")
    CREATED_EVENT_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    REASSIGNMENT_COUNTER_FIELD_NUMBER: _ClassVar[int]
    created_event: _event_pb2.CreatedEvent
    domain_id: str
    reassignment_counter: int
    def __init__(self, created_event: _Optional[_Union[_event_pb2.CreatedEvent, _Mapping]] = ..., domain_id: _Optional[str] = ..., reassignment_counter: _Optional[int] = ...) -> None: ...

class IncompleteUnassigned(_message.Message):
    __slots__ = ("created_event", "unassigned_event")
    CREATED_EVENT_FIELD_NUMBER: _ClassVar[int]
    UNASSIGNED_EVENT_FIELD_NUMBER: _ClassVar[int]
    created_event: _event_pb2.CreatedEvent
    unassigned_event: _reassignment_pb2.UnassignedEvent
    def __init__(self, created_event: _Optional[_Union[_event_pb2.CreatedEvent, _Mapping]] = ..., unassigned_event: _Optional[_Union[_reassignment_pb2.UnassignedEvent, _Mapping]] = ...) -> None: ...

class IncompleteAssigned(_message.Message):
    __slots__ = ("assigned_event",)
    ASSIGNED_EVENT_FIELD_NUMBER: _ClassVar[int]
    assigned_event: _reassignment_pb2.AssignedEvent
    def __init__(self, assigned_event: _Optional[_Union[_reassignment_pb2.AssignedEvent, _Mapping]] = ...) -> None: ...

class GetConnectedDomainsRequest(_message.Message):
    __slots__ = ("party", "participant_id")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_ID_FIELD_NUMBER: _ClassVar[int]
    party: str
    participant_id: str
    def __init__(self, party: _Optional[str] = ..., participant_id: _Optional[str] = ...) -> None: ...

class GetConnectedDomainsResponse(_message.Message):
    __slots__ = ("connected_domains",)
    class ConnectedDomain(_message.Message):
        __slots__ = ("domain_alias", "domain_id", "permission")
        DOMAIN_ALIAS_FIELD_NUMBER: _ClassVar[int]
        DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
        PERMISSION_FIELD_NUMBER: _ClassVar[int]
        domain_alias: str
        domain_id: str
        permission: ParticipantPermission
        def __init__(self, domain_alias: _Optional[str] = ..., domain_id: _Optional[str] = ..., permission: _Optional[_Union[ParticipantPermission, str]] = ...) -> None: ...
    CONNECTED_DOMAINS_FIELD_NUMBER: _ClassVar[int]
    connected_domains: _containers.RepeatedCompositeFieldContainer[GetConnectedDomainsResponse.ConnectedDomain]
    def __init__(self, connected_domains: _Optional[_Iterable[_Union[GetConnectedDomainsResponse.ConnectedDomain, _Mapping]]] = ...) -> None: ...

class GetLedgerEndRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLedgerEndResponse(_message.Message):
    __slots__ = ("offset",)
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    offset: int
    def __init__(self, offset: _Optional[int] = ...) -> None: ...

class GetLatestPrunedOffsetsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetLatestPrunedOffsetsResponse(_message.Message):
    __slots__ = ("participant_pruned_up_to_inclusive", "all_divulged_contracts_pruned_up_to_inclusive")
    PARTICIPANT_PRUNED_UP_TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    ALL_DIVULGED_CONTRACTS_PRUNED_UP_TO_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    participant_pruned_up_to_inclusive: int
    all_divulged_contracts_pruned_up_to_inclusive: int
    def __init__(self, participant_pruned_up_to_inclusive: _Optional[int] = ..., all_divulged_contracts_pruned_up_to_inclusive: _Optional[int] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/domain_connectivity.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/domain_connectivity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....domain.api.v0 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_domain_dot_api_dot_v0_dot_sequencer__connection__pb2
from ....time.admin.v0 import time_tracker_config_pb2 as com_dot_digitalasset_dot_canton_dot_time_dot_admin_dot_v0_dot_time__tracker__config__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/participant/admin/v0/domain_connectivity.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a@com/digitalasset/canton/domain/api/v0/sequencer_connection.proto\x1a?com/digitalasset/canton/time/admin/v0/time_tracker_config.proto\x1a\x1egoogle/protobuf/duration.proto\"\xb1\x04\n\x16\x44omainConnectionConfig\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12n\n\x14sequencerConnections\x18\x02 \x03(\x0b\x32:.com.digitalasset.canton.domain.api.v0.SequencerConnectionR\x14sequencerConnections\x12%\n\x0emanual_connect\x18\x03 \x01(\x08R\rmanualConnect\x12\x1b\n\tdomain_id\x18\x04 \x01(\tR\x08\x64omainId\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12G\n\x11initialRetryDelay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11initialRetryDelay\x12?\n\rmaxRetryDelay\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rmaxRetryDelay\x12`\n\x0btimeTracker\x18\x08 \x01(\x0b\x32>.com.digitalasset.canton.time.admin.v0.DomainTimeTrackerConfigR\x0btimeTracker\x12\x38\n\x17sequencerTrustThreshold\x18\t \x01(\rR\x17sequencerTrustThreshold\"B\n\x17ReconnectDomainsRequest\x12\'\n\x0fignore_failures\x18\x01 \x01(\x08R\x0eignoreFailures\"\x1a\n\x18ReconnectDomainsResponse\"o\n\x15RegisterDomainRequest\x12V\n\x03\x61\x64\x64\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.admin.v0.DomainConnectionConfigR\x03\x61\x64\x64\"\x18\n\x16RegisterDomainResponse\"s\n\x13ModifyDomainRequest\x12\\\n\x06modify\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.admin.v0.DomainConnectionConfigR\x06modify\"\x16\n\x14ModifyDomainResponse\"\x1e\n\x1cListConfiguredDomainsRequest\"\x94\x02\n\x1dListConfiguredDomainsResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.participant.admin.v0.ListConfiguredDomainsResponse.ResultR\x07results\x1a\x84\x01\n\x06Result\x12\\\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x44.com.digitalasset.canton.participant.admin.v0.DomainConnectionConfigR\x06\x63onfig\x12\x1c\n\tconnected\x18\x02 \x01(\x08R\tconnected\"O\n\x14\x43onnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x14\n\x05retry\x18\x02 \x01(\x08R\x05retry\"N\n\x15\x43onnectDomainResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"<\n\x17\x44isconnectDomainRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"\x1a\n\x18\x44isconnectDomainResponse\"\x1d\n\x1bListConnectedDomainsRequest\"\x82\x02\n\x1cListConnectedDomainsResponse\x12~\n\x11\x63onnected_domains\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.participant.admin.v0.ListConnectedDomainsResponse.ResultR\x10\x63onnectedDomains\x1a\x62\n\x06Result\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12\x18\n\x07healthy\x18\x03 \x01(\x08R\x07healthy\"8\n\x13GetAgreementRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"\xa6\x01\n\x14GetAgreementResponse\x12\x1b\n\tdomain_id\x18\x01 \x01(\tR\x08\x64omainId\x12U\n\tagreement\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.participant.admin.v0.AgreementR\tagreement\x12\x1a\n\x08\x61\x63\x63\x65pted\x18\x03 \x01(\x08R\x08\x61\x63\x63\x65pted\"/\n\tAgreement\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04text\x18\x02 \x01(\tR\x04text\"^\n\x16\x41\x63\x63\x65ptAgreementRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\x12!\n\x0c\x61greement_id\x18\x02 \x01(\tR\x0b\x61greementId\"\x19\n\x17\x41\x63\x63\x65ptAgreementResponse\"7\n\x12GetDomainIdRequest\x12!\n\x0c\x64omain_alias\x18\x01 \x01(\tR\x0b\x64omainAlias\"2\n\x13GetDomainIdResponse\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId2\xe5\x0c\n\x19\x44omainConnectivityService\x12\xa1\x01\n\x10ReconnectDomains\x12\x45.com.digitalasset.canton.participant.admin.v0.ReconnectDomainsRequest\x1a\x46.com.digitalasset.canton.participant.admin.v0.ReconnectDomainsResponse\x12\x9b\x01\n\x0eRegisterDomain\x12\x43.com.digitalasset.canton.participant.admin.v0.RegisterDomainRequest\x1a\x44.com.digitalasset.canton.participant.admin.v0.RegisterDomainResponse\x12\x95\x01\n\x0cModifyDomain\x12\x41.com.digitalasset.canton.participant.admin.v0.ModifyDomainRequest\x1a\x42.com.digitalasset.canton.participant.admin.v0.ModifyDomainResponse\x12\x98\x01\n\rConnectDomain\x12\x42.com.digitalasset.canton.participant.admin.v0.ConnectDomainRequest\x1a\x43.com.digitalasset.canton.participant.admin.v0.ConnectDomainResponse\x12\xa1\x01\n\x10\x44isconnectDomain\x12\x45.com.digitalasset.canton.participant.admin.v0.DisconnectDomainRequest\x1a\x46.com.digitalasset.canton.participant.admin.v0.DisconnectDomainResponse\x12\xad\x01\n\x14ListConnectedDomains\x12I.com.digitalasset.canton.participant.admin.v0.ListConnectedDomainsRequest\x1aJ.com.digitalasset.canton.participant.admin.v0.ListConnectedDomainsResponse\x12\xb0\x01\n\x15ListConfiguredDomains\x12J.com.digitalasset.canton.participant.admin.v0.ListConfiguredDomainsRequest\x1aK.com.digitalasset.canton.participant.admin.v0.ListConfiguredDomainsResponse\x12\x95\x01\n\x0cGetAgreement\x12\x41.com.digitalasset.canton.participant.admin.v0.GetAgreementRequest\x1a\x42.com.digitalasset.canton.participant.admin.v0.GetAgreementResponse\x12\x9e\x01\n\x0f\x41\x63\x63\x65ptAgreement\x12\x44.com.digitalasset.canton.participant.admin.v0.AcceptAgreementRequest\x1a\x45.com.digitalasset.canton.participant.admin.v0.AcceptAgreementResponse\x12\x92\x01\n\x0bGetDomainId\x12@.com.digitalasset.canton.participant.admin.v0.GetDomainIdRequest\x1a\x41.com.digitalasset.canton.participant.admin.v0.GetDomainIdResponseB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.domain_connectivity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_start=284
  _globals['_DOMAINCONNECTIONCONFIG']._serialized_end=845
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_start=847
  _globals['_RECONNECTDOMAINSREQUEST']._serialized_end=913
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_start=915
  _globals['_RECONNECTDOMAINSRESPONSE']._serialized_end=941
  _globals['_REGISTERDOMAINREQUEST']._serialized_start=943
  _globals['_REGISTERDOMAINREQUEST']._serialized_end=1054
  _globals['_REGISTERDOMAINRESPONSE']._serialized_start=1056
  _globals['_REGISTERDOMAINRESPONSE']._serialized_end=1080
  _globals['_MODIFYDOMAINREQUEST']._serialized_start=1082
  _globals['_MODIFYDOMAINREQUEST']._serialized_end=1197
  _globals['_MODIFYDOMAINRESPONSE']._serialized_start=1199
  _globals['_MODIFYDOMAINRESPONSE']._serialized_end=1221
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_start=1223
  _globals['_LISTCONFIGUREDDOMAINSREQUEST']._serialized_end=1253
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_start=1256
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE']._serialized_end=1532
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_start=1400
  _globals['_LISTCONFIGUREDDOMAINSRESPONSE_RESULT']._serialized_end=1532
  _globals['_CONNECTDOMAINREQUEST']._serialized_start=1534
  _globals['_CONNECTDOMAINREQUEST']._serialized_end=1613
  _globals['_CONNECTDOMAINRESPONSE']._serialized_start=1615
  _globals['_CONNECTDOMAINRESPONSE']._serialized_end=1693
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_start=1695
  _globals['_DISCONNECTDOMAINREQUEST']._serialized_end=1755
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_start=1757
  _globals['_DISCONNECTDOMAINRESPONSE']._serialized_end=1783
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_start=1785
  _globals['_LISTCONNECTEDDOMAINSREQUEST']._serialized_end=1814
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_start=1817
  _globals['_LISTCONNECTEDDOMAINSRESPONSE']._serialized_end=2075
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_start=1977
  _globals['_LISTCONNECTEDDOMAINSRESPONSE_RESULT']._serialized_end=2075
  _globals['_GETAGREEMENTREQUEST']._serialized_start=2077
  _globals['_GETAGREEMENTREQUEST']._serialized_end=2133
  _globals['_GETAGREEMENTRESPONSE']._serialized_start=2136
  _globals['_GETAGREEMENTRESPONSE']._serialized_end=2302
  _globals['_AGREEMENT']._serialized_start=2304
  _globals['_AGREEMENT']._serialized_end=2351
  _globals['_ACCEPTAGREEMENTREQUEST']._serialized_start=2353
  _globals['_ACCEPTAGREEMENTREQUEST']._serialized_end=2447
  _globals['_ACCEPTAGREEMENTRESPONSE']._serialized_start=2449
  _globals['_ACCEPTAGREEMENTRESPONSE']._serialized_end=2474
  _globals['_GETDOMAINIDREQUEST']._serialized_start=2476
  _globals['_GETDOMAINIDREQUEST']._serialized_end=2531
  _globals['_GETDOMAINIDRESPONSE']._serialized_start=2533
  _globals['_GETDOMAINIDRESPONSE']._serialized_end=2583
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_start=2586
  _globals['_DOMAINCONNECTIVITYSERVICE']._serialized_end=4223
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import trace_context_pb2 as _trace_context_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.rpc import status_pb2 as _status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Completion(_message.Message):
    __slots__ = ("command_id", "status", "transaction_id", "application_id", "act_as", "submission_id", "deduplication_offset", "deduplication_duration", "trace_context")
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    command_id: str
    status: _status_pb2.Status
    transaction_id: str
    application_id: str
    act_as: _containers.RepeatedScalarFieldContainer[str]
    submission_id: str
    deduplication_offset: str
    deduplication_duration: _duration_pb2.Duration
    trace_context: _trace_context_pb2.TraceContext
    def __init__(self, command_id: _Optional[str] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., transaction_id: _Optional[str] = ..., application_id: _Optional[str] = ..., act_as: _Optional[_Iterable[str]] = ..., submission_id: _Optional[str] = ..., deduplication_offset: _Optional[str] = ..., deduplication_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., trace_context: _Optional[_Union[_trace_context_pb2.TraceContext, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

from typing import TYPE_CHECKING, Any, Protocol

from ..damlast.daml_lf_1 import DefDataType, Type

if TYPE_CHECKING:
    from .context import Context


__all__ = ["ValueMapper"]


class ValueMapper(Protocol):
    """
    Protocol for an object that can map one representation of DAML-LF values to another
    representation. This is the protocol that wire encoders/decoders adhere to, as well as certain
    types of validators.

    To use an instance of a :class:`ValueMapper` to transform an object, create a :class:`Context`
    with an instance of a :class:`ValueMapper`; then call :meth:`Context.convert`.
    """

    def data_record(
        self, context: Context, dt: DefDataType, record: DefDataType.Fields, obj: Any
    ) -> Any:
        raise NotImplementedError("data_record requires an implementation")

    def data_variant(
        self, context: Context, dt: DefDataType, variant: DefDataType.Fields, obj: Any
    ) -> Any:
        raise NotImplementedError("data_variant requires an implementation")

    def data_enum(
        self,
        context: Context,
        dt: DefDataType,
        enum: DefDataType.EnumConstructors,
        obj: Any,
    ) -> Any:
        raise NotImplementedError("data_variant requires an implementation")

    def prim_unit(self, context: Context, obj: Any) -> Any:
        raise NotImplementedError("prim_unit requires an implementation")

    def prim_bool(self, context: Context, obj: Any) -> Any:
        raise NotImplementedError("prim_bool requires an implementation")

    def prim_int64(self, context: Context, obj: Any) -> Any:
        raise NotImplementedError("prim_int64 requires an implementation")

    def prim_text(self, context: Context, obj: Any) -> Any:
        raise NotImplementedError("prim_text requires an implementation")

    def prim_timestamp(self, context: Context, obj: Any) -> Any:
        raise NotImplementedError("prim_timestamp requires an implementation")

    def prim_party(self, context: Context, obj: Any) -> Any:
        raise NotImplementedError("prim_party requires an implementation")

    def prim_list(self, context: Context, item_type: Type, obj: Any) -> Any:
        raise NotImplementedError("prim_list requires an implementation")

    def prim_date(self, context: Context, obj: Any) -> Any:
        raise NotImplementedError("prim_date requires an implementation")

    def prim_contract_id(self, context: Context, item_type: Type, obj: Any) -> Any:
        raise NotImplementedError("prim_contract_id requires an implementation")

    def prim_optional(self, context: Context, item_type: Type, obj: Any) -> Any:
        raise NotImplementedError("prim_optional requires an implementation")

    def prim_text_map(self, context: Context, item_type: Type, obj: Any) -> Any:
        raise NotImplementedError("prim_text_map requires an implementation")

    def prim_numeric(self, context: Context, nat: int, obj: Any) -> Any:
        raise NotImplementedError("prim_numeric requires an implementation")

    def prim_gen_map(self, context: Context, key_type: Type, value_type: Type, obj: Any) -> Any:
        raise NotImplementedError("prim_gen_map requires an implementation")



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OffsetCheckpoint(_message.Message):
    __slots__ = ("offset", "domain_times")
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_TIMES_FIELD_NUMBER: _ClassVar[int]
    offset: int
    domain_times: _containers.RepeatedCompositeFieldContainer[DomainTime]
    def __init__(self, offset: _Optional[int] = ..., domain_times: _Optional[_Iterable[_Union[DomainTime, _Mapping]]] = ...) -> None: ...

class DomainTime(_message.Message):
    __slots__ = ("domain_id", "record_time")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    RECORD_TIME_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    record_time: _timestamp_pb2.Timestamp
    def __init__(self, domain_id: _Optional[str] = ..., record_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v1 import common_pb2 as _common_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SerializableContract(_message.Message):
    __slots__ = ("contract_id", "raw_contract_instance", "metadata", "ledger_create_time", "contract_salt")
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    RAW_CONTRACT_INSTANCE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    LEDGER_CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_SALT_FIELD_NUMBER: _ClassVar[int]
    contract_id: str
    raw_contract_instance: bytes
    metadata: _common_pb2.Metadata
    ledger_create_time: _timestamp_pb2.Timestamp
    contract_salt: _crypto_pb2.Salt
    def __init__(self, contract_id: _Optional[str] = ..., raw_contract_instance: _Optional[bytes] = ..., metadata: _Optional[_Union[_common_pb2.Metadata, _Mapping]] = ..., ledger_create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., contract_salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/quorum.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v0/quorum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0com/digitalasset/canton/protocol/v0/quorum.proto\x12#com.digitalasset.canton.protocol.v0\x1a\x32\x63om/digitalasset/canton/protocol/v0/topology.proto\"\x95\x01\n\x06Quorum\x12m\n\x16party_index_and_weight\x18\x01 \x03(\x0b\x32\x38.com.digitalasset.canton.protocol.v0.PartyIndexAndWeightR\x13partyIndexAndWeight\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold\"C\n\x13PartyIndexAndWeight\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x12\x16\n\x06weight\x18\x02 \x01(\x05R\x06weight\"\x85\x01\n\nTrustParty\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x61\n\x14required_trust_level\x18\x02 \x01(\x0e\x32/.com.digitalasset.canton.protocol.v0.TrustLevelR\x12requiredTrustLevelBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.quorum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_QUORUM']._serialized_start=142
  _globals['_QUORUM']._serialized_end=291
  _globals['_PARTYINDEXANDWEIGHT']._serialized_start=293
  _globals['_PARTYINDEXANDWEIGHT']._serialized_end=360
  _globals['_TRUSTPARTY']._serialized_start=363
  _globals['_TRUSTPARTY']._serialized_end=496
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/admin/v0/resource_management_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/participant/admin/v0/resource_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/participant/admin/v0/resource_management_service.proto\x12,com.digitalasset.canton.participant.admin.v0\x1a\x1bgoogle/protobuf/empty.proto\"\x83\x01\n\x0eResourceLimits\x12,\n\x12max_dirty_requests\x18\x01 \x01(\x05R\x10maxDirtyRequests\x12\x19\n\x08max_rate\x18\x02 \x01(\x05R\x07maxRate\x12(\n\x10max_burst_factor\x18\x03 \x01(\x01R\x0emaxBurstFactor2\xf4\x01\n\x19ResourceManagementService\x12l\n\x14UpdateResourceLimits\x12<.com.digitalasset.canton.participant.admin.v0.ResourceLimits\x1a\x16.google.protobuf.Empty\x12i\n\x11GetResourceLimits\x12\x16.google.protobuf.Empty\x1a<.com.digitalasset.canton.participant.admin.v0.ResourceLimitsB]Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.admin.v0.resource_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z[github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/admin/v0'
  _globals['_RESOURCELIMITS']._serialized_start=158
  _globals['_RESOURCELIMITS']._serialized_end=289
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_start=292
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_end=536
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import common_pb2 as _common_pb2
from ..v0 import participant_transaction_pb2 as _participant_transaction_pb2
from ..v0 import topology_pb2 as _topology_pb2
from . import common_pb2 as _common_pb2_1
from . import merkle_pb2 as _merkle_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ActionDescription(_message.Message):
    __slots__ = ("create", "exercise", "fetch", "lookup_by_key")
    class ExerciseActionDescription(_message.Message):
        __slots__ = ("input_contract_id", "choice", "chosen_value", "actors", "by_key", "node_seed", "version", "failed", "interface_id")
        INPUT_CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        CHOICE_FIELD_NUMBER: _ClassVar[int]
        CHOSEN_VALUE_FIELD_NUMBER: _ClassVar[int]
        ACTORS_FIELD_NUMBER: _ClassVar[int]
        BY_KEY_FIELD_NUMBER: _ClassVar[int]
        NODE_SEED_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
        input_contract_id: str
        choice: str
        chosen_value: bytes
        actors: _containers.RepeatedScalarFieldContainer[str]
        by_key: bool
        node_seed: bytes
        version: str
        failed: bool
        interface_id: str
        def __init__(self, input_contract_id: _Optional[str] = ..., choice: _Optional[str] = ..., chosen_value: _Optional[bytes] = ..., actors: _Optional[_Iterable[str]] = ..., by_key: bool = ..., node_seed: _Optional[bytes] = ..., version: _Optional[str] = ..., failed: bool = ..., interface_id: _Optional[str] = ...) -> None: ...
    class LookupByKeyActionDescription(_message.Message):
        __slots__ = ("key",)
        KEY_FIELD_NUMBER: _ClassVar[int]
        key: _common_pb2_1.GlobalKey
        def __init__(self, key: _Optional[_Union[_common_pb2_1.GlobalKey, _Mapping]] = ...) -> None: ...
    class FetchActionDescription(_message.Message):
        __slots__ = ("input_contract_id", "actors", "by_key", "version", "template_id")
        INPUT_CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        ACTORS_FIELD_NUMBER: _ClassVar[int]
        BY_KEY_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
        input_contract_id: str
        actors: _containers.RepeatedScalarFieldContainer[str]
        by_key: bool
        version: str
        template_id: str
        def __init__(self, input_contract_id: _Optional[str] = ..., actors: _Optional[_Iterable[str]] = ..., by_key: bool = ..., version: _Optional[str] = ..., template_id: _Optional[str] = ...) -> None: ...
    CREATE_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_FIELD_NUMBER: _ClassVar[int]
    FETCH_FIELD_NUMBER: _ClassVar[int]
    LOOKUP_BY_KEY_FIELD_NUMBER: _ClassVar[int]
    create: _participant_transaction_pb2.ActionDescription.CreateActionDescription
    exercise: ActionDescription.ExerciseActionDescription
    fetch: _participant_transaction_pb2.ActionDescription.FetchActionDescription
    lookup_by_key: _participant_transaction_pb2.ActionDescription.LookupByKeyActionDescription
    def __init__(self, create: _Optional[_Union[_participant_transaction_pb2.ActionDescription.CreateActionDescription, _Mapping]] = ..., exercise: _Optional[_Union[ActionDescription.ExerciseActionDescription, _Mapping]] = ..., fetch: _Optional[_Union[_participant_transaction_pb2.ActionDescription.FetchActionDescription, _Mapping]] = ..., lookup_by_key: _Optional[_Union[_participant_transaction_pb2.ActionDescription.LookupByKeyActionDescription, _Mapping]] = ...) -> None: ...

class ViewNode(_message.Message):
    __slots__ = ("view_common_data", "view_participant_data", "subviews")
    VIEW_COMMON_DATA_FIELD_NUMBER: _ClassVar[int]
    VIEW_PARTICIPANT_DATA_FIELD_NUMBER: _ClassVar[int]
    SUBVIEWS_FIELD_NUMBER: _ClassVar[int]
    view_common_data: _merkle_pb2.BlindableNode
    view_participant_data: _merkle_pb2.BlindableNode
    subviews: _merkle_pb2.MerkleSeq
    def __init__(self, view_common_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ..., view_participant_data: _Optional[_Union[_merkle_pb2.BlindableNode, _Mapping]] = ..., subviews: _Optional[_Union[_merkle_pb2.MerkleSeq, _Mapping]] = ...) -> None: ...

class ViewCommonData(_message.Message):
    __slots__ = ("salt", "informees", "threshold")
    SALT_FIELD_NUMBER: _ClassVar[int]
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    informees: _containers.RepeatedCompositeFieldContainer[Informee]
    threshold: int
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., informees: _Optional[_Iterable[_Union[Informee, _Mapping]]] = ..., threshold: _Optional[int] = ...) -> None: ...

class Informee(_message.Message):
    __slots__ = ("party", "weight", "required_trust_level")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_TRUST_LEVEL_FIELD_NUMBER: _ClassVar[int]
    party: str
    weight: int
    required_trust_level: _topology_pb2.TrustLevel
    def __init__(self, party: _Optional[str] = ..., weight: _Optional[int] = ..., required_trust_level: _Optional[_Union[_topology_pb2.TrustLevel, str]] = ...) -> None: ...

class EncryptedViewMessage(_message.Message):
    __slots__ = ("view_tree", "encryption_scheme", "submitter_participant_signature", "view_hash", "randomness", "domain_id", "view_type")
    VIEW_TREE_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_SCHEME_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_PARTICIPANT_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    VIEW_HASH_FIELD_NUMBER: _ClassVar[int]
    RANDOMNESS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    view_tree: bytes
    encryption_scheme: _crypto_pb2.SymmetricKeyScheme
    submitter_participant_signature: _crypto_pb2.Signature
    view_hash: bytes
    randomness: _containers.RepeatedCompositeFieldContainer[ParticipantRandomnessLookup]
    domain_id: str
    view_type: _common_pb2.ViewType
    def __init__(self, view_tree: _Optional[bytes] = ..., encryption_scheme: _Optional[_Union[_crypto_pb2.SymmetricKeyScheme, str]] = ..., submitter_participant_signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., view_hash: _Optional[bytes] = ..., randomness: _Optional[_Iterable[_Union[ParticipantRandomnessLookup, _Mapping]]] = ..., domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ...) -> None: ...

class ParticipantRandomnessLookup(_message.Message):
    __slots__ = ("randomness", "fingerprint")
    RANDOMNESS_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    randomness: bytes
    fingerprint: str
    def __init__(self, randomness: _Optional[bytes] = ..., fingerprint: _Optional[str] = ...) -> None: ...

class ViewParticipantMessage(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class InformeeMessage(_message.Message):
    __slots__ = ("full_informee_tree", "protocol_version")
    FULL_INFORMEE_TREE_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    full_informee_tree: FullInformeeTree
    protocol_version: int
    def __init__(self, full_informee_tree: _Optional[_Union[FullInformeeTree, _Mapping]] = ..., protocol_version: _Optional[int] = ...) -> None: ...

class LightTransactionViewTree(_message.Message):
    __slots__ = ("tree", "subview_hashes")
    TREE_FIELD_NUMBER: _ClassVar[int]
    SUBVIEW_HASHES_FIELD_NUMBER: _ClassVar[int]
    tree: _merkle_pb2.GenTransactionTree
    subview_hashes: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, tree: _Optional[_Union[_merkle_pb2.GenTransactionTree, _Mapping]] = ..., subview_hashes: _Optional[_Iterable[bytes]] = ...) -> None: ...

class FullInformeeTree(_message.Message):
    __slots__ = ("tree",)
    TREE_FIELD_NUMBER: _ClassVar[int]
    tree: _merkle_pb2.GenTransactionTree
    def __init__(self, tree: _Optional[_Union[_merkle_pb2.GenTransactionTree, _Mapping]] = ...) -> None: ...

class CreatedContract(_message.Message):
    __slots__ = ("contract", "consumed_in_core", "rolled_back")
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    CONSUMED_IN_CORE_FIELD_NUMBER: _ClassVar[int]
    ROLLED_BACK_FIELD_NUMBER: _ClassVar[int]
    contract: _common_pb2_1.SerializableContract
    consumed_in_core: bool
    rolled_back: bool
    def __init__(self, contract: _Optional[_Union[_common_pb2_1.SerializableContract, _Mapping]] = ..., consumed_in_core: bool = ..., rolled_back: bool = ...) -> None: ...

class InputContract(_message.Message):
    __slots__ = ("contract", "consumed")
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    CONSUMED_FIELD_NUMBER: _ClassVar[int]
    contract: _common_pb2_1.SerializableContract
    consumed: bool
    def __init__(self, contract: _Optional[_Union[_common_pb2_1.SerializableContract, _Mapping]] = ..., consumed: bool = ...) -> None: ...

class SubmitterMetadata(_message.Message):
    __slots__ = ("salt", "act_as", "application_id", "command_id", "submitter_participant", "submission_id", "dedup_period", "max_sequencing_time")
    SALT_FIELD_NUMBER: _ClassVar[int]
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    DEDUP_PERIOD_FIELD_NUMBER: _ClassVar[int]
    MAX_SEQUENCING_TIME_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    act_as: _containers.RepeatedScalarFieldContainer[str]
    application_id: str
    command_id: str
    submitter_participant: str
    submission_id: str
    dedup_period: _participant_transaction_pb2.DeduplicationPeriod
    max_sequencing_time: _timestamp_pb2.Timestamp
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., act_as: _Optional[_Iterable[str]] = ..., application_id: _Optional[str] = ..., command_id: _Optional[str] = ..., submitter_participant: _Optional[str] = ..., submission_id: _Optional[str] = ..., dedup_period: _Optional[_Union[_participant_transaction_pb2.DeduplicationPeriod, _Mapping]] = ..., max_sequencing_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ResolvedKey(_message.Message):
    __slots__ = ("key", "contract_id", "free")
    KEY_FIELD_NUMBER: _ClassVar[int]
    CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
    FREE_FIELD_NUMBER: _ClassVar[int]
    key: _common_pb2_1.GlobalKey
    contract_id: str
    free: _participant_transaction_pb2.ViewParticipantData.FreeKey
    def __init__(self, key: _Optional[_Union[_common_pb2_1.GlobalKey, _Mapping]] = ..., contract_id: _Optional[str] = ..., free: _Optional[_Union[_participant_transaction_pb2.ViewParticipantData.FreeKey, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import base64
from dataclasses import dataclass
import json
import os
from pathlib import Path
import sys
from typing import TYPE_CHECKING, AbstractSet, Any, Collection, Mapping, Optional, TypedDict

from ...prim import Parties, Party, to_parties
from ..auth import TokenOrTokenProvider, V1TokenNamespace

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = [
    "AccessConfig",
    "AccessConfigArgs",
    "create_access",
]

if TYPE_CHECKING:
    # We refer to the Config class in a docstring and
    # without this import, Sphinx can't resolve the reference
    # noinspection PyUnresolvedReferences
    from . import Config


def parties_from_env(*env_vars: str) -> Optional[AbstractSet[Party]]:
    """
    Read the set of parties
    """
    env_values = [os.getenv(env_var, "") for env_var in env_vars]
    if sum(map(len, env_values)) == 0:
        return None
    return {Party(p) for env_value in env_values for p in env_value.split(",") if p}


class AccessConfigArgs(TypedDict, total=False):
    user_id: Optional[str]
    read_as: Optional[Parties]
    act_as: Optional[Parties]
    admin: Optional[bool]
    ledger_id: Optional[str]
    application_name: Optional[str]
    token: Optional[TokenOrTokenProvider]
    oauth_token: Optional[str]
    oauth_token_file: Optional[str]


def create_access(**kwargs: Unpack[AccessConfigArgs]) -> AccessConfig:
    """
    Create an appropriate instance of :class:`AccessConfig`.

    See :meth:`Config.create` for a more detailed description of these parameters.
    """
    user_id = kwargs.get("user_id", os.getenv("DAML_USER_ID", ""))
    read_as = kwargs.get("read_as", parties_from_env("DAML_LEDGER_READ_AS", "DABL_PUBLIC_PARTY"))
    act_as = kwargs.get("act_as", parties_from_env("DAML_LEDGER_ACT_AS", "DAML_LEDGER_PARTY"))
    admin = kwargs.get("admin", None)
    ledger_id = kwargs.get("ledger_id", os.getenv("DAML_LEDGER_ID", ""))
    application_name = kwargs.get("application_name", os.getenv("DAML_LEDGER_APPLICATION_NAME"))

    token = kwargs.get("token", None)
    if token is None:
        oauth_token = kwargs.get("oauth_token", os.getenv("DAML_LEDGER_OAUTH_TOKEN"))
        if oauth_token:
            token = oauth_token
        else:
            oauth_token_file = kwargs.get(
                "oauth_token_file", os.getenv("DAML_LEDGER_OAUTH_TOKEN_FILE")
            )
            if oauth_token_file is not None:
                token = lambda: Path(oauth_token_file).read_text().strip()

    return AccessConfig(
        user_id=user_id,
        read_as=read_as,
        act_as=act_as,
        admin=admin,
        ledger_id=ledger_id,
        application_name=application_name,
        token=token,
    )


def parties(*pp: Optional[Collection[str]]) -> Parties:
    s = set[Party]()
    for p in pp:
        if p is not None:
            s.update(to_parties(p))
    return sorted(s)


@dataclass
class AccessConfig:
    """
    Configuration parameters for providing access to a ledger.
    """

    user_id: Optional[str]
    read_as: Optional[Parties]
    act_as: Optional[Parties]
    admin: Optional[bool]
    ledger_id: Optional[str]
    application_name: Optional[str]
    token: Optional[TokenOrTokenProvider]

    def __init__(
        self,
        *,
        user_id: Optional[str] = None,
        read_as: Optional[Parties] = None,
        act_as: Optional[Parties] = None,
        admin: Optional[bool] = None,
        ledger_id: Optional[str] = None,
        application_name: Optional[str] = None,
        token: Optional[TokenOrTokenProvider] = None,
    ) -> None:
        self.user_id = user_id
        self.read_as = read_as
        self.act_as = act_as
        self.admin = admin
        self.ledger_id = ledger_id
        self.application_name = application_name
        self.token = token


def decode_token_claims(token: str) -> Mapping[str, Any]:
    """
    Decode the claims section from a JSON Web Token (JWT).

    Note that the signature is NOT verified; this is the responsibility of the caller!
    """
    components = token.split(".", 3)
    if len(components) != 3:
        raise ValueError("not a JWT")

    pad_bytes = "=" * (-len(components[1]) % 4)
    claim_str = base64.urlsafe_b64decode(components[1] + pad_bytes)
    return json.loads(claim_str)


def encode_unsigned_token(
    read_as: Optional[Collection[Party]],
    act_as: Optional[Collection[Party]],
    ledger_id: Optional[str],
    application_id: Optional[str],
    admin: bool = True,
) -> bytes:
    header = {
        "alg": "none",
        "typ": "JWT",
    }
    payload = {V1TokenNamespace: {}}  # type: Mapping[str, Any]
    if ledger_id is not None:
        payload[V1TokenNamespace]["ledgerId"] = ledger_id
    if application_id is not None:
        payload[V1TokenNamespace]["applicationId"] = application_id
    if act_as is not None:
        payload[V1TokenNamespace]["actAs"] = sorted(act_as)
    if read_as is not None:
        payload[V1TokenNamespace]["readAs"] = sorted(read_as)
    if admin:
        payload[V1TokenNamespace]["admin"] = admin

    return (
        base64.urlsafe_b64encode(json.dumps(header).encode("utf-8")).rstrip(b"=")
        + b"."
        + base64.urlsafe_b64encode(json.dumps(payload).encode("utf-8")).rstrip(b"=")
        + b"."
    )



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import daml_lf_1_pb2 as _daml_lf_1_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HashFunction(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SHA256: _ClassVar[HashFunction]
SHA256: HashFunction

class ArchivePayload(_message.Message):
    __slots__ = ("minor", "daml_lf_1", "daml_lf_2")
    MINOR_FIELD_NUMBER: _ClassVar[int]
    DAML_LF_1_FIELD_NUMBER: _ClassVar[int]
    DAML_LF_2_FIELD_NUMBER: _ClassVar[int]
    minor: str
    daml_lf_1: _daml_lf_1_pb2.Package
    daml_lf_2: bytes
    def __init__(self, minor: _Optional[str] = ..., daml_lf_1: _Optional[_Union[_daml_lf_1_pb2.Package, _Mapping]] = ..., daml_lf_2: _Optional[bytes] = ...) -> None: ...

class Archive(_message.Message):
    __slots__ = ("hash_function", "payload", "hash")
    HASH_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    hash_function: HashFunction
    payload: bytes
    hash: str
    def __init__(self, hash_function: _Optional[_Union[HashFunction, str]] = ..., payload: _Optional[bytes] = ..., hash: _Optional[str] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...v30 import crypto_pb2 as _crypto_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenerateCertificateRequest(_message.Message):
    __slots__ = ("unique_identifier", "certificate_key", "additional_subject", "subject_alternative_names")
    UNIQUE_IDENTIFIER_FIELD_NUMBER: _ClassVar[int]
    CERTIFICATE_KEY_FIELD_NUMBER: _ClassVar[int]
    ADDITIONAL_SUBJECT_FIELD_NUMBER: _ClassVar[int]
    SUBJECT_ALTERNATIVE_NAMES_FIELD_NUMBER: _ClassVar[int]
    unique_identifier: str
    certificate_key: str
    additional_subject: str
    subject_alternative_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, unique_identifier: _Optional[str] = ..., certificate_key: _Optional[str] = ..., additional_subject: _Optional[str] = ..., subject_alternative_names: _Optional[_Iterable[str]] = ...) -> None: ...

class GenerateCertificateResponse(_message.Message):
    __slots__ = ("x509_cert",)
    X509_CERT_FIELD_NUMBER: _ClassVar[int]
    x509_cert: str
    def __init__(self, x509_cert: _Optional[str] = ...) -> None: ...

class ListCertificateRequest(_message.Message):
    __slots__ = ("filter_uid",)
    FILTER_UID_FIELD_NUMBER: _ClassVar[int]
    filter_uid: str
    def __init__(self, filter_uid: _Optional[str] = ...) -> None: ...

class ListCertificateResponse(_message.Message):
    __slots__ = ("results",)
    class Result(_message.Message):
        __slots__ = ("x509_cert",)
        X509_CERT_FIELD_NUMBER: _ClassVar[int]
        x509_cert: str
        def __init__(self, x509_cert: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ListCertificateResponse.Result]
    def __init__(self, results: _Optional[_Iterable[_Union[ListCertificateResponse.Result, _Mapping]]] = ...) -> None: ...

class ImportCertificateRequest(_message.Message):
    __slots__ = ("x509_cert",)
    X509_CERT_FIELD_NUMBER: _ClassVar[int]
    x509_cert: str
    def __init__(self, x509_cert: _Optional[str] = ...) -> None: ...

class ImportCertificateResponse(_message.Message):
    __slots__ = ("certificate_id",)
    CERTIFICATE_ID_FIELD_NUMBER: _ClassVar[int]
    certificate_id: str
    def __init__(self, certificate_id: _Optional[str] = ...) -> None: ...

class ImportPublicKeyRequest(_message.Message):
    __slots__ = ("public_key", "name")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    public_key: bytes
    name: str
    def __init__(self, public_key: _Optional[bytes] = ..., name: _Optional[str] = ...) -> None: ...

class ImportPublicKeyResponse(_message.Message):
    __slots__ = ("fingerprint",)
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    fingerprint: str
    def __init__(self, fingerprint: _Optional[str] = ...) -> None: ...

class ListKeysFilters(_message.Message):
    __slots__ = ("fingerprint", "name", "purpose")
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PURPOSE_FIELD_NUMBER: _ClassVar[int]
    fingerprint: str
    name: str
    purpose: _containers.RepeatedScalarFieldContainer[_crypto_pb2.KeyPurpose]
    def __init__(self, fingerprint: _Optional[str] = ..., name: _Optional[str] = ..., purpose: _Optional[_Iterable[_Union[_crypto_pb2.KeyPurpose, str]]] = ...) -> None: ...

class ListMyKeysRequest(_message.Message):
    __slots__ = ("filters",)
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    filters: ListKeysFilters
    def __init__(self, filters: _Optional[_Union[ListKeysFilters, _Mapping]] = ...) -> None: ...

class ListPublicKeysRequest(_message.Message):
    __slots__ = ("filters",)
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    filters: ListKeysFilters
    def __init__(self, filters: _Optional[_Union[ListKeysFilters, _Mapping]] = ...) -> None: ...

class PrivateKeyMetadata(_message.Message):
    __slots__ = ("public_key_with_name", "wrapper_key_id")
    PUBLIC_KEY_WITH_NAME_FIELD_NUMBER: _ClassVar[int]
    WRAPPER_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    public_key_with_name: _crypto_pb2.PublicKeyWithName
    wrapper_key_id: str
    def __init__(self, public_key_with_name: _Optional[_Union[_crypto_pb2.PublicKeyWithName, _Mapping]] = ..., wrapper_key_id: _Optional[str] = ...) -> None: ...

class ListMyKeysResponse(_message.Message):
    __slots__ = ("private_keys_metadata",)
    PRIVATE_KEYS_METADATA_FIELD_NUMBER: _ClassVar[int]
    private_keys_metadata: _containers.RepeatedCompositeFieldContainer[PrivateKeyMetadata]
    def __init__(self, private_keys_metadata: _Optional[_Iterable[_Union[PrivateKeyMetadata, _Mapping]]] = ...) -> None: ...

class ListPublicKeysResponse(_message.Message):
    __slots__ = ("public_keys",)
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    public_keys: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.PublicKeyWithName]
    def __init__(self, public_keys: _Optional[_Iterable[_Union[_crypto_pb2.PublicKeyWithName, _Mapping]]] = ...) -> None: ...

class GenerateSigningKeyRequest(_message.Message):
    __slots__ = ("key_scheme", "name")
    KEY_SCHEME_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    key_scheme: _crypto_pb2.SigningKeyScheme
    name: str
    def __init__(self, key_scheme: _Optional[_Union[_crypto_pb2.SigningKeyScheme, str]] = ..., name: _Optional[str] = ...) -> None: ...

class GenerateSigningKeyResponse(_message.Message):
    __slots__ = ("public_key",)
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: _crypto_pb2.SigningPublicKey
    def __init__(self, public_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ...) -> None: ...

class GenerateEncryptionKeyRequest(_message.Message):
    __slots__ = ("key_spec", "name")
    KEY_SPEC_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    key_spec: _crypto_pb2.EncryptionKeySpec
    name: str
    def __init__(self, key_spec: _Optional[_Union[_crypto_pb2.EncryptionKeySpec, str]] = ..., name: _Optional[str] = ...) -> None: ...

class GenerateEncryptionKeyResponse(_message.Message):
    __slots__ = ("public_key",)
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: _crypto_pb2.EncryptionPublicKey
    def __init__(self, public_key: _Optional[_Union[_crypto_pb2.EncryptionPublicKey, _Mapping]] = ...) -> None: ...

class RegisterKmsSigningKeyRequest(_message.Message):
    __slots__ = ("kms_key_id", "name")
    KMS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    kms_key_id: str
    name: str
    def __init__(self, kms_key_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class RegisterKmsSigningKeyResponse(_message.Message):
    __slots__ = ("public_key",)
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: _crypto_pb2.SigningPublicKey
    def __init__(self, public_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ...) -> None: ...

class RegisterKmsEncryptionKeyRequest(_message.Message):
    __slots__ = ("kms_key_id", "name")
    KMS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    kms_key_id: str
    name: str
    def __init__(self, kms_key_id: _Optional[str] = ..., name: _Optional[str] = ...) -> None: ...

class RegisterKmsEncryptionKeyResponse(_message.Message):
    __slots__ = ("public_key",)
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    public_key: _crypto_pb2.EncryptionPublicKey
    def __init__(self, public_key: _Optional[_Union[_crypto_pb2.EncryptionPublicKey, _Mapping]] = ...) -> None: ...

class RotateWrapperKeyRequest(_message.Message):
    __slots__ = ("new_wrapper_key_id",)
    NEW_WRAPPER_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    new_wrapper_key_id: str
    def __init__(self, new_wrapper_key_id: _Optional[str] = ...) -> None: ...

class RotateWrapperKeyResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetWrapperKeyIdRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetWrapperKeyIdResponse(_message.Message):
    __slots__ = ("wrapper_key_id",)
    WRAPPER_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    wrapper_key_id: str
    def __init__(self, wrapper_key_id: _Optional[str] = ...) -> None: ...

class ExportKeyPairRequest(_message.Message):
    __slots__ = ("fingerprint", "protocol_version", "password")
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_VERSION_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    fingerprint: str
    protocol_version: int
    password: str
    def __init__(self, fingerprint: _Optional[str] = ..., protocol_version: _Optional[int] = ..., password: _Optional[str] = ...) -> None: ...

class ExportKeyPairResponse(_message.Message):
    __slots__ = ("key_pair",)
    KEY_PAIR_FIELD_NUMBER: _ClassVar[int]
    key_pair: bytes
    def __init__(self, key_pair: _Optional[bytes] = ...) -> None: ...

class ImportKeyPairRequest(_message.Message):
    __slots__ = ("key_pair", "name", "password")
    KEY_PAIR_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    key_pair: bytes
    name: str
    password: str
    def __init__(self, key_pair: _Optional[bytes] = ..., name: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class ImportKeyPairResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteKeyPairRequest(_message.Message):
    __slots__ = ("fingerprint",)
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    fingerprint: str
    def __init__(self, fingerprint: _Optional[str] = ...) -> None: ...

class DeleteKeyPairResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import package_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2

GRPC_GENERATED_VERSION = '1.67.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in com/digitalasset/canton/admin/participant/v30/package_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PackageServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPackages = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/ListPackages',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackagesRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackagesResponse.FromString,
                _registered_method=True)
        self.ListPackageContents = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/ListPackageContents',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackageContentsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackageContentsResponse.FromString,
                _registered_method=True)
        self.ListDars = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/ListDars',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarsResponse.FromString,
                _registered_method=True)
        self.ListDarContents = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/ListDarContents',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarContentsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarContentsResponse.FromString,
                _registered_method=True)
        self.UploadDar = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/UploadDar',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UploadDarRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UploadDarResponse.FromString,
                _registered_method=True)
        self.ValidateDar = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/ValidateDar',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ValidateDarRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ValidateDarResponse.FromString,
                _registered_method=True)
        self.RemovePackage = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/RemovePackage',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemovePackageRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemovePackageResponse.FromString,
                _registered_method=True)
        self.VetDar = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/VetDar',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.VetDarRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.VetDarResponse.FromString,
                _registered_method=True)
        self.UnvetDar = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/UnvetDar',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UnvetDarRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UnvetDarResponse.FromString,
                _registered_method=True)
        self.RemoveDar = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/RemoveDar',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemoveDarRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemoveDarResponse.FromString,
                _registered_method=True)
        self.GetDar = channel.unary_unary(
                '/com.digitalasset.canton.admin.participant.v30.PackageService/GetDar',
                request_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.GetDarRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.GetDarResponse.FromString,
                _registered_method=True)


class PackageServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPackageContents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDars(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDarContents(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadDar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemovePackage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VetDar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnvetDar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveDar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PackageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPackages,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackagesRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackagesResponse.SerializeToString,
            ),
            'ListPackageContents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPackageContents,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackageContentsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackageContentsResponse.SerializeToString,
            ),
            'ListDars': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDars,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarsResponse.SerializeToString,
            ),
            'ListDarContents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDarContents,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarContentsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarContentsResponse.SerializeToString,
            ),
            'UploadDar': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadDar,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UploadDarRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UploadDarResponse.SerializeToString,
            ),
            'ValidateDar': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDar,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ValidateDarRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ValidateDarResponse.SerializeToString,
            ),
            'RemovePackage': grpc.unary_unary_rpc_method_handler(
                    servicer.RemovePackage,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemovePackageRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemovePackageResponse.SerializeToString,
            ),
            'VetDar': grpc.unary_unary_rpc_method_handler(
                    servicer.VetDar,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.VetDarRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.VetDarResponse.SerializeToString,
            ),
            'UnvetDar': grpc.unary_unary_rpc_method_handler(
                    servicer.UnvetDar,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UnvetDarRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UnvetDarResponse.SerializeToString,
            ),
            'RemoveDar': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveDar,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemoveDarRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemoveDarResponse.SerializeToString,
            ),
            'GetDar': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDar,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.GetDarRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.GetDarResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.admin.participant.v30.PackageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.admin.participant.v30.PackageService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PackageService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/ListPackages',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackagesRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPackageContents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/ListPackageContents',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackageContentsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListPackageContentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/ListDars',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDarContents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/ListDarContents',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarContentsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ListDarContentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UploadDar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/UploadDar',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UploadDarRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UploadDarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateDar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/ValidateDar',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ValidateDarRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.ValidateDarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemovePackage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/RemovePackage',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemovePackageRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemovePackageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VetDar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/VetDar',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.VetDarRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.VetDarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnvetDar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/UnvetDar',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UnvetDarRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.UnvetDarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveDar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/RemoveDar',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemoveDarRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.RemoveDarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.admin.participant.v30.PackageService/GetDar',
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.GetDarRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_package__service__pb2.GetDarResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
